( cd usr/lib64 ; rm -rf libgnome-desktop-3.so )
( cd usr/lib64 ; ln -sf libgnome-desktop-3.so.19 libgnome-desktop-3.so )
( cd usr/lib64 ; rm -rf libgnome-desktop-3.so.19 )
( cd usr/lib64 ; ln -sf libgnome-desktop-3.so.19.1.11 libgnome-desktop-3.so.19 )
